==> CGAL-6.0.1-doc_html.tar.xz: doc_html/Polygon_mesh_processing/index.js <==
var index =
[
    [ "Introduction", "index.html#PMPIntroduction", [
      [ "Polygon Mesh", "index.html#PMPDef", null ],
      [ "API", "index.html#PMPAPI", null ],
      [ "Outline", "index.html#PMPOutline", null ],
      [ "Reading and Writing Polygon Meshes", "index.html#PMPIO", null ]
    ] ],
    [ "Meshing", "index.html#PMPMeshing", [
      [ "API", "index.html#MeshingAPI", [
        [ "Meshing", "index.html#Meshing", null ],
        [ "Remeshing", "index.html#Remeshing", [
          [ "Isotropic Incremental Remeshing", "index.html#Local", null ],
          [ "Surface Remeshing", "index.html#Delaunay-Based", null ],
          [ "Remeshing of (Almost) Planar Patches", "index.html#Decimate", null ]
        ] ],
        [ "Smoothing", "index.html#Smoothing", null ],
        [ "Extrusion", "index.html#Extrusion", null ]
      ] ],
      [ "Meshing Examples", "index.html#MeshingExamples", [
        [ "Refine and Fair a Region on a Triangle Mesh", "index.html#MeshingExample_1", null ],
        [ "Triangulate a Polygon Mesh", "index.html#MeshingExample_2", null ],
        [ "Isotropic Remeshing of a Region on a Polygon Mesh", "index.html#RemeshingExample_1", null ],
        [ "Extrusion of a Triangle Mesh", "index.html#ExtrusionExample", null ]
      ] ]
    ] ],
    [ "Corefinement and Boolean Operations", "index.html#Coref_section", [
      [ "Definitions", "index.html#coref_def_subsec", null ],
      [ "Corefinement", "index.html#coref_coref_subsec", null ],
      [ "Boolean Operations", "index.html#coref_bolop_subsec", null ],
      [ "Kernel and Validity of the Output", "index.html#coref_valid_subsec", null ],
      [ "Clipping", "index.html#coref_clip", null ],
      [ "Examples", "index.html#coref_ex_subsec", [
        [ "Computing the Union of Two Volumes", "index.html#coref_ex_union_subsec", null ],
        [ "Boolean Operation and Local Remeshing", "index.html#coref_ex_refine_subsec", null ],
        [ "Robustness of Consecutive Operations", "index.html#coref_ex_consq_subsec", null ]
      ] ]
    ] ],
    [ "Hole Filling", "index.html#PMPHoleFilling", [
      [ "API", "index.html#HoleFillingAPI", null ],
      [ "Examples", "index.html#HFExamples", [
        [ "Triangulate a Polyline", "index.html#HFExample_1", null ],
        [ "Hole Filling From the Border of the Hole", "index.html#HFExample_2", null ]
      ] ],
      [ "Performance", "index.html#HFPerformance", null ]
    ] ],
    [ "Predicates", "index.html#PMPPredicates", [
      [ "Intersections Detection", "index.html#PMPDoIntersect", [
        [ "Self Intersections", "index.html#PMPSelIntersections", null ],
        [ "Self Intersections Example", "index.html#SIExample", null ]
      ] ],
      [ "Side of Triangle Mesh", "index.html#PMPInsideTest", [
        [ "Inside Test Example", "index.html#InsideExample", null ]
      ] ],
      [ "Polyhedral Envelope Containment Check", "index.html#PMPEnvelope", [
        [ "Polyhedral Envelope Example", "index.html#PolyhedralEnvelopeExample", null ]
      ] ],
      [ "Shape Predicates", "index.html#PMPShapePredicates", null ],
      [ "Surface Location Functions", "index.html#PMPLocationFunctions", null ]
    ] ],
    [ "Orientation", "index.html#PMPOrientation", [
      [ "Polygon Soups", "index.html#PMPPolygonSoups", null ],
      [ "Polygon Meshes", "index.html#OrientingPolygonMeshes", null ],
      [ "Orientation Examples", "index.html#PolygonSoupExample", null ]
    ] ],
    [ "Combinatorial Repair", "index.html#PMPCombinatorialRepair", [
      [ "Polygon Soup Repairing", "index.html#PSRepairing", null ],
      [ "Stitching", "index.html#Stitching", [
        [ "Stitching Example", "index.html#StitchingExample", null ]
      ] ],
      [ "Polygon Mesh Manifoldness", "index.html#PMPManifoldness", [
        [ "Manifoldness Repair Example", "index.html#FixNMVerticeExample", null ]
      ] ],
      [ "Duplicated Vertices in Boundary Cycles", "index.html#PMPDuplicateVertexBoundaryCycle", null ]
    ] ],
    [ "Geometric Repair", "index.html#PMPGeometricRepair", [
      [ "Self-intersection Resolution (Autorefinement) in Triangle Soups", "index.html#PMPAutoref", null ],
      [ "Removal of Almost Degenerate Triangle Faces", "index.html#PMPRemoveCapsNeedles", null ]
    ] ],
    [ "Computing Normals", "index.html#PMPNormalComp", [
      [ "Normals Computation Examples", "index.html#NormalsExample", [
        [ "Normals Computation for a Surface Mesh", "index.html#NormalsExampleSM", null ],
        [ "Normals Computation for a Polyhedron_3", "index.html#NormalsExampleP", null ]
      ] ]
    ] ],
    [ "Computing Curvatures", "index.html#PMPICC", [
      [ "Brief Background", "index.html#ICCBackground", null ],
      [ "API", "index.html#ICCAPI", null ],
      [ "Results", "index.html#ICCResults", null ],
      [ "Performance", "index.html#ICCPerformance", null ],
      [ "Interpolated Corrected Curvatures on a Surface Mesh Example", "index.html#ICCExampleSM", null ],
      [ "Interpolated Corrected Curvatures on a Polyhedron Example", "index.html#ICCExamplePH", null ],
      [ "Interpolated Corrected Curvatures on a Vertex Example", "index.html#ICCExampleSV", null ]
    ] ],
    [ "Slicer", "index.html#PMPSlicer", [
      [ "Slicer Example", "index.html#SlicerExample", null ]
    ] ],
    [ "Connected Components", "index.html#PMPConnectedComponents", [
      [ "Connected Components Example", "index.html#CCExample", null ]
    ] ],
    [ "Hausdorff Distance", "index.html#PMPDistance", [
      [ "Approximate Hausdorff Distance", "index.html#ApproxHD", [
        [ "Approximate Hausdorff Distance Example", "index.html#AHDExample", null ],
        [ "Max Distance Between Point Set and Surface Example", "index.html#PoissonDistanceExample", null ]
      ] ],
      [ "Bounded Hausdorff Distance", "index.html#BoundedHD", [
        [ "Bounded Hausdorff Distance Example", "index.html#BHDExample", null ]
      ] ]
    ] ],
    [ "Feature Detection", "index.html#PMPDetectFeatures", [
      [ "Feature Detection Example", "index.html#DetectFeaturesExample", null ]
    ] ],
    [ "Implementation History", "index.html#PMPHistory", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Polygon_mesh_processing/index.js <==
var index =
[
    [ "Introduction", "index.html#PMPIntroduction", [
      [ "Polygon Mesh", "index.html#PMPDef", null ],
      [ "API", "index.html#PMPAPI", null ],
      [ "Outline", "index.html#PMPOutline", null ],
      [ "Reading and Writing Polygon Meshes", "index.html#PMPIO", null ]
    ] ],
    [ "Meshing", "index.html#PMPMeshing", [
      [ "API", "index.html#MeshingAPI", [
        [ "Meshing", "index.html#Meshing", null ],
        [ "Remeshing", "index.html#Remeshing", [
          [ "Local Isotropic Incremental Remeshing", "index.html#isorem", null ],
          [ "Delaunay-Based Surface Remeshing", "index.html#mesh3rem", null ],
          [ "Approximated Discrete Centroidal Voronoi Diagram (ACVD) Remeshing", "index.html#acvdrem", null ],
          [ "Remeshing of (Almost) Planar Patches", "index.html#decimate", null ]
        ] ],
        [ "Smoothing", "index.html#Smoothing", null ],
        [ "Extrusion", "index.html#Extrusion", null ]
      ] ],
      [ "Meshing Examples", "index.html#MeshingExamples", [
        [ "Refine and Fair a Region on a Triangle Mesh", "index.html#MeshingExample_1", null ],
        [ "Triangulate a Polygon Mesh", "index.html#MeshingExample_2", null ],
        [ "Isotropic Remeshing of a Region on a Polygon Mesh", "index.html#RemeshingExample_1", null ],
        [ "Extrusion of a Triangle Mesh", "index.html#ExtrusionExample", null ]
      ] ]
    ] ],
    [ "Corefinement and Boolean Operations", "index.html#Coref_section", [
      [ "Definitions", "index.html#coref_def_subsec", null ],
      [ "Corefinement", "index.html#coref_coref_subsec", null ],
      [ "Boolean Operations", "index.html#coref_bolop_subsec", null ],
      [ "Kernel and Validity of the Output", "index.html#coref_valid_subsec", null ],
      [ "Clipping", "index.html#coref_clip", null ],
      [ "Examples", "index.html#coref_ex_subsec", [
        [ "Computing the Union of Two Volumes", "index.html#coref_ex_union_subsec", null ],
        [ "Boolean Operation and Local Remeshing", "index.html#coref_ex_refine_subsec", null ],
        [ "Robustness of Consecutive Operations", "index.html#coref_ex_consq_subsec", null ]
      ] ]
    ] ],
    [ "Hole Filling", "index.html#PMPHoleFilling", [
      [ "API", "index.html#HoleFillingAPI", null ],
      [ "Examples", "index.html#HFExamples", [
        [ "Triangulate a Polyline", "index.html#HFExample_1", null ],
        [ "Hole Filling From the Border of the Hole", "index.html#HFExample_2", null ]
      ] ],
      [ "Performance", "index.html#HFPerformance", null ]
    ] ],
    [ "Predicates", "index.html#PMPPredicates", [
      [ "Intersections Detection", "index.html#PMPDoIntersect", [
        [ "Self Intersections", "index.html#PMPSelIntersections", null ],
        [ "Self Intersections Example", "index.html#SIExample", null ]
      ] ],
      [ "Side of Triangle Mesh", "index.html#PMPInsideTest", [
        [ "Inside Test Example", "index.html#InsideExample", null ]
      ] ],
      [ "Polyhedral Envelope Containment Check", "index.html#PMPEnvelope", [
        [ "Polyhedral Envelope Example", "index.html#PolyhedralEnvelopeExample", null ]
      ] ],
      [ "Shape Predicates", "index.html#PMPShapePredicates", null ],
      [ "Surface Location Functions", "index.html#PMPLocationFunctions", null ]
    ] ],
    [ "Orientation", "index.html#PMPOrientation", [
      [ "Polygon Soups", "index.html#PMPPolygonSoups", null ],
      [ "Polygon Meshes", "index.html#OrientingPolygonMeshes", null ],
      [ "Orientation Examples", "index.html#PolygonSoupExample", null ]
    ] ],
    [ "Combinatorial Repair", "index.html#PMPCombinatorialRepair", [
      [ "Polygon Soup Repairing", "index.html#PSRepairing", null ],
      [ "Stitching", "index.html#Stitching", [
        [ "Stitching Example", "index.html#StitchingExample", null ]
      ] ],
      [ "Polygon Mesh Manifoldness", "index.html#PMPManifoldness", [
        [ "Manifoldness Repair Example", "index.html#FixNMVerticeExample", null ]
      ] ],
      [ "Duplicated Vertices in Boundary Cycles", "index.html#PMPDuplicateVertexBoundaryCycle", null ]
    ] ],
    [ "Geometric Repair", "index.html#PMPGeometricRepair", [
      [ "Self-intersection Resolution (Autorefinement) in Triangle Soups", "index.html#PMPAutoref", null ],
      [ "Removal of Almost Degenerate Triangle Faces", "index.html#PMPRemoveCapsNeedles", null ]
    ] ],
    [ "Computing Normals", "index.html#PMPNormalComp", [
      [ "Normals Computation Examples", "index.html#NormalsExample", [
        [ "Normals Computation for a Surface Mesh", "index.html#NormalsExampleSM", null ],
        [ "Normals Computation for a Polyhedron_3", "index.html#NormalsExampleP", null ]
      ] ]
    ] ],
    [ "Computing Curvatures", "index.html#PMPICC", [
      [ "Brief Background", "index.html#ICCBackground", null ],
      [ "API", "index.html#ICCAPI", null ],
      [ "Results", "index.html#ICCResults", null ],
      [ "Performance", "index.html#ICCPerformance", null ],
      [ "Interpolated Corrected Curvatures on a Surface Mesh Example", "index.html#ICCExampleSM", null ],
      [ "Interpolated Corrected Curvatures on a Polyhedron Example", "index.html#ICCExamplePH", null ],
      [ "Interpolated Corrected Curvatures on a Vertex Example", "index.html#ICCExampleSV", null ],
      [ "Discrete Curvatures", "index.html#DCurvartures", null ]
    ] ],
    [ "Slicer", "index.html#PMPSlicer", [
      [ "Slicer Example", "index.html#SlicerExample", null ]
    ] ],
    [ "Connected Components", "index.html#PMPConnectedComponents", [
      [ "Connected Components Example", "index.html#CCExample", null ]
    ] ],
    [ "Hausdorff Distance", "index.html#PMPDistance", [
      [ "Approximate Hausdorff Distance", "index.html#ApproxHD", [
        [ "Approximate Hausdorff Distance Example", "index.html#AHDExample", null ],
        [ "Max Distance Between Point Set and Surface Example", "index.html#PoissonDistanceExample", null ]
      ] ],
      [ "Bounded Hausdorff Distance", "index.html#BoundedHD", [
        [ "Bounded Hausdorff Distance Example", "index.html#BHDExample", null ]
      ] ]
    ] ],
    [ "Feature Detection", "index.html#PMPDetectFeatures", [
      [ "Feature Detection Example", "index.html#DetectFeaturesExample", null ]
    ] ],
    [ "Implementation History", "index.html#PMPHistory", null ]
];
